@@ -7,9 +7,9 @@
 #' @param reflection logical: if TRUE "rigid" and "similarity" allow reflections.
 #' @param lambda numeric: regularisation parameter of the TPS.
 #' @param weights vector of length k, containing weights for each landmark (only used in type="rigid" or "similarity").
-#' @param centerweight logical: if weights are defined and centerweigths=TRUE,
-#' the matrix will be centered according to these weights instead of the
-#' barycenter.
+#' @param centerweight logical or vector of weights: if weights are defined and
+#' centerweigths=TRUE, the matrix will be centered according to these weights instead of the
+#' barycenter. If centerweight is a vector of length \code{nrow(x)}, the barycenter will be weighted accordingly.
 #' @param threads number of threads to use in TPS interpolation.
 #' @details
 #' \code{x} and \code{y} can also be a pair of meshes with corresponding vertices.
@@ -24,19 +24,21 @@
 computeTransform <- function(x,y,type=c("rigid","similarity","affine","tps"),reflection=FALSE,lambda=1e-8, weights=NULL,centerweight=FALSE,threads=1) {
     if (inherits(x,"mesh3d"))
         x <- vert2points(x)
-     if (inherits(y,"mesh3d"))
+    if (inherits(y,"mesh3d"))
         y <- vert2points(y)
     type <- substr(type[1],1L,1L)
-    ##check for missing entries
-    xrows <- rowSums(x)
-    yrows <- rowSums(y)
-    xbad <- which(as.logical(is.na(xrows) + is.nan(xrows)))
-    ybad <- which(as.logical(is.na(yrows) + is.nan(yrows)))
-    bad <- unique(c(xbad,ybad))
-    if (length(bad)) {
-        message("some landmarks are missing and ignored for calculating the transform")
-        x <- x[-bad,]
-        y <- y[-bad,]
+    ##check for missing entries in case of tps
+    if (type == "t") {
+        xrows <- rowSums(x)
+        yrows <- rowSums(y)
+        xbad <- which(as.logical(is.na(xrows) + is.nan(xrows)))
+        ybad <- which(as.logical(is.na(yrows) + is.nan(yrows)))
+        bad <- unique(c(xbad,ybad))
+        if (length(bad)) {
+            message("some landmarks are missing and ignored for calculating the transform")
+            x <- x[-bad,,drop=FALSE]
+            y <- y[-bad,,drop=FALSE]
+        }
     }
     if (type %in% c("r","s")) {
         scale <- TRUE
@@ -70,6 +72,6 @@ computeTransform <- function(x,y,type=c("rigid","similarity","affine","tps"),ref
     } else {
         stop("Unknown transformation type")
     }
-        
+
     return(trafo)
 }
